=======================
Configuration Reference
=======================

This section provides a list of all configuration options for various
networking_cisco drivers and plugins. These are auto-generated from
networking_cisco code when this documentation was built.

The filenames listed below are just examples. Often times the neutron
configuration options are combined into one or two configuration files
(ex. neutron.conf, ml2_conf.ini) which are added on the neutron-server
command line via the "--config-file" option.

Configuration Options
=====================

.. toctree::
   :maxdepth: 1

   ml2-nexus
   ml2-nexus-vxlan-type-driver
   ml2-ucsm

Sample Configuration Files
==========================

.. toctree::
   :maxdepth: 1

   samples/l3-asr1k
   samples/ml2-nexus
   samples/ml2-nexus-vxlan-type-driver
   samples/ml2-ucsm
